# frozen_string_literal: true

require "bloomfilter-rb"

module Wayfarer
  module Frontiers
    # An in-memory bloomfilter.
    # @api private
    class MemoryBloomfilter < MemoryFrontier
      def initialize(config)
        @filter = BloomFilter::Native.new(config.bloomfilter_opts)
        super(config)
      end

      # @override
      def cache(*uris)
        uris.each { |uri| @filter.insert(uri) }
      end

      # @override
      def cached?(uri)
        @filter.include?(uri)
      end

      # Frees up memory.
      def free
        @filter.clear
        super
      end
    end
  end
end
